@@ -1,7 +1,7 @@
 
 ;;;### (autoloads nil "_pkg" "auctex/_pkg.el")
 
-(package-provide 'auctex :version 2012.113 :author-version "11.87" :type 'regular)
+(package-provide 'auctex :version 2014.1029 :author-version "11.88" :type 'regular)
 
 ;;;***
 
@@ -58,7 +58,7 @@ Special commands:
 
 Entering `context-mode' calls the value of `text-mode-hook',
 then the value of `TeX-mode-hook', and then the value
-of context-mode-hook." t nil)
+of ConTeXt-mode-hook." t nil)
 
 ;;;***
 
@@ -223,6 +223,8 @@ Set `japanese-TeX-mode' to t, and enter `TeX-latex-mode'." t nil)
 
 ;;;### (autoloads (TeX-submit-bug-report TeX-auto-generate-global TeX-auto-generate TeX-tex-mode) "tex" "auctex/tex.el")
 
+(defalias 'TeX-assoc-string (symbol-function (if (featurep 'xemacs) 'assoc 'assoc-string)))
+
 (autoload 'TeX-tex-mode "tex" "\
 Major mode in AUCTeX for editing TeX or LaTeX files.
 Tries to guess whether this file is for plain TeX or LaTeX.
@@ -327,7 +329,7 @@ Limit searched to BOUND." nil nil)
   :load "tex" :load "latex" :load "tex-style")
 
 (defvar TeX-lisp-directory
-  (file-name-directory load-file-name)
+  (directory-file-name (file-name-directory load-file-name))
   "The directory where most of the AUCTeX lisp files are located.
 For the location of lisp files associated with
 styles, see the variables TeX-style-* (hand-generated lisp) and
@@ -336,11 +338,11 @@ TeX-auto-* (automatically generated lisp).")
 (add-to-list 'load-path TeX-lisp-directory)
 
 (defvar TeX-data-directory
-  (expand-file-name "../../etc/auctex/" (file-name-directory load-file-name))
+  (expand-file-name "../../etc/auctex" (file-name-directory load-file-name))
   "The directory where the AUCTeX non-Lisp data is located.")
 
 (defcustom TeX-auto-global
-    (expand-file-name "../../etc/auctex/auto/" (file-name-directory load-file-name))
+    (expand-file-name "../../etc/auctex/auto" (file-name-directory load-file-name))
   "*Directory containing automatically generated information.
 Must end with a directory separator.
 
@@ -390,13 +392,18 @@ definition."
   (let ((list TeX-mode-alist) elt)
     (while list
       (setq elt (car (pop list)))
-      (when (or update (null (get elt 'tex-saved)))
-	(when (fboundp elt)
-	  (put elt 'tex-saved (symbol-function elt))))
-      (defalias elt
-	(if (memq elt value)
-	    (intern (concat "TeX-" (symbol-name elt)))
-	  (get elt 'tex-saved))))))
+      (let ((dst (intern (concat "TeX-" (symbol-name elt)))))
+        (if (fboundp 'advice-add)
+            (if (memq elt value)
+                (advice-add elt :override dst)
+              (advice-remove elt dst))
+          (when (or update (null (get elt 'tex-saved)))
+            (when (fboundp elt)
+              (put elt 'tex-saved (symbol-function elt))))
+          (defalias elt
+            (if (memq elt value)
+                dst
+              (get elt 'tex-saved))))))))
 
 (defcustom TeX-modes
   (mapcar 'car TeX-mode-alist)
@@ -408,19 +415,20 @@ set it with `TeX-modes-set'."
 	      (mapcar (lambda(x) (list 'const (car x))) TeX-mode-alist))
   :set 'TeX-modes-set
   :group 'AUCTeX
-  :initialize (lambda (var value)
-		(custom-initialize-reset var value)
-		(let ((list TeX-mode-alist))
-		  (while list
-		    (eval-after-load (cdar list)
-		      `(TeX-modes-set ',var ,var t))
-		    (setq list (cdr list))))))
+  :initialize(lambda (var value)
+	       (custom-initialize-reset var value)
+	       (unless (fboundp 'advice-add)
+		 (let ((list TeX-mode-alist))
+		   (while list
+		     (eval-after-load (cdar list)
+		       `(TeX-modes-set ',var ,var t))
+		     (setq list (cdr list)))))) )
 
-(defconst AUCTeX-version "11.87"
+(defconst AUCTeX-version "11.88"
     "AUCTeX version.
 If not a regular release, the date of the last change.")
 
-(defconst AUCTeX-date "2012-11-30"
+(defconst AUCTeX-date "2014-10-29"
   "AUCTeX release date using the ISO 8601 format, yyyy-mm-dd.")
 
 ;; Store bibitems when saving a BibTeX buffer
@@ -428,6 +436,7 @@ If not a regular release, the date of the last change.")
 
 (provide 'tex-site)
 
-(add-to-list 'load-path (file-name-directory load-file-name))
-(defvar preview-datadir (expand-file-name "../../etc/auctex/" (file-name-directory load-file-name)))
-(defvar preview-TeX-style-dir (expand-file-name "../../etc/auctex/latex/" (file-name-directory load-file-name)))
+(defvar preview-lispdir (directory-file-name (file-name-directory load-file-name)))
+(add-to-list 'load-path preview-lispdir)
+(defvar preview-datadir (expand-file-name "../../etc/auctex" (file-name-directory load-file-name)))
+(defvar preview-TeX-style-dir (expand-file-name "../../etc/auctex/latex" (file-name-directory load-file-name)))
